Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2410)

Unified Diff: ash/frame/caption_buttons/frame_caption_button_container_view.h

Issue 2906803002: Rename MaximizeMode to TabletMode (Closed)
Patch Set: updated filter Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/frame/caption_buttons/frame_caption_button_container_view.h
diff --git a/ash/frame/caption_buttons/frame_caption_button_container_view.h b/ash/frame/caption_buttons/frame_caption_button_container_view.h
index 93bd98b2ecc6ec933d1a9b7396525537bb304e04..747189315da73b88f1de285f4f6398efab446d6a 100644
--- a/ash/frame/caption_buttons/frame_caption_button_container_view.h
+++ b/ash/frame/caption_buttons/frame_caption_button_container_view.h
@@ -88,7 +88,7 @@ class ASH_EXPORT FrameCaptionButtonContainerView
int NonClientHitTest(const gfx::Point& point) const;
// Updates the size button's visibility based on whether |frame_| can be
// maximized and if maximize mode is enabled. A parent view should relayout
// to reflect the change in visibility.
void UpdateSizeButtonVisibility();
@@ -115,7 +115,7 @@ class ASH_EXPORT FrameCaptionButtonContainerView
CaptionButtonIcon icon,
Animate animate);
// Returns true if maximize mode is not enabled, and |frame_| widget delegate
// can be maximized.
bool ShouldSizeButtonBeVisible() const;
@@ -148,7 +148,7 @@ class ASH_EXPORT FrameCaptionButtonContainerView
// Animation that affects the position of |minimize_button_| and the
// visibility of |size_button_|.
- std::unique_ptr<gfx::SlideAnimation> maximize_mode_animation_;
+ std::unique_ptr<gfx::SlideAnimation> tablet_mode_animation_;
DISALLOW_COPY_AND_ASSIGN(FrameCaptionButtonContainerView);
};
@@ -88,7 +88,7 @@ class ASH_EXPORT FrameCaptionButtonContainerView
int NonClientHitTest(const gfx::Point& point) const;
// Updates the size button's visibility based on whether |frame_| can be
- // maximized and if maximize mode is enabled. A parent view should relayout
+ // maximized and if tablet mode is enabled. A parent view should relayout
// to reflect the change in visibility.
void UpdateSizeButtonVisibility();
@@ -115,7 +115,7 @@ class ASH_EXPORT FrameCaptionButtonContainerView
CaptionButtonIcon icon,
Animate animate);
- // Returns true if maximize mode is not enabled, and |frame_| widget delegate
+ // Returns true if tablet mode is not enabled, and |frame_| widget delegate
// can be maximized.
bool ShouldSizeButtonBeVisible() const;

Powered by Google App Engine
This is Rietveld 408576698